{% load i18n %}

<p>Step {{ wizard.steps.step1 }} of {{ wizard.steps.count }}</p>
<form action="" method="post">
    {% csrf_token %}
    {{ wizard.management_form }}
    <table>
        <caption>{{ wizard.form.get_question_text }}</caption>
        {{ wizard.form }}
    </table>

    <button type="submit">{% trans "Next" %}</button>
</form>
